==> 1.0.2_20240315_release.zip: app/utils/base/plugin/tags/Tag_category_plugin.php <==
<?php

namespace app\utils\base\plugin\tags;

class Tag_category_plugin
{
    /**
     * 选择多行列表
     */
    public function getMultiHtml($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "field"=>"id,name,pid",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $result=$checkResult["result"];
                $result=app("ltcmsFormat")->recursionArr($result);//递归组装
                $selectMap=array();
                if(isset($condition["selectId"]) && isset($condition["dataId"])){
                    if($final_arr["error_no"]==0)
                    {
                        $paramsObj=paramsObj();
                        $paramsObj->params=array(
                            'dataType' =>$condition["dataType"],
                            'dataId' => $condition["dataId"],
                            'id' => $condition["selectId"],
                        );
                        $checkResult=app("S_Admin_category")->getParentVal($paramsObj);
                        if($checkResult["error_no"]==0){
                            $selectMap=$checkResult["result"];
                            $selectMap["data"]=array_column($selectMap["data"],"id");
                        }else{
                            $final_arr=logCallErrorMsg($final_arr,$checkResult);
                        }
                    }
                }
                if($final_arr["error_no"]==0)
                {
                    $result=app("ltcmsFormat")->recursionToMultihtml($result,$selectMap);  //转换成html
                    $return=array();
                    $return["type"]="echo";
                    $return["data"]=$result;
                    $final_arr["result"]= $return;
                }
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    /**
     * 选择数据html
     */
    public function getHtml($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "field"=>"id,name,pid",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $result=$checkResult["result"];
                $result=app("ltcmsFormat")->recursionArr($result);//递归组装
                if(isset($condition["selectId"])){
                    $result=app("ltcmsFormat")->recursionTohtml($result,$condition["selectId"]);  //转换成html
                }else{
                    $result=app("ltcmsFormat")->recursionTohtml($result);  //转换成html
                }
                $return=array();
                $return["type"]="echo";
                $return["data"]=$result;
                $final_arr["result"]= $return;
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    /**
     * 分类显示
     */
    public function show($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "disabled"=>"1",
                "field"=>"id,name,catDir,linkurl,dataType,dataId",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            if(isset($paramsObj->params["pid"])){
                if(!is_numeric($paramsObj->params["pid"])){
                    $paramsObj->params["pid"]=0;
                }
            }else{
                $paramsObj->params["pid"]=0;
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $final_arr["result"]= $checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}

?>

==> 1.0.20_20240718_release.zip: app/utils/base/plugin/tags/Tag_category_plugin.php <==
<?php

namespace app\utils\base\plugin\tags;

class Tag_category_plugin
{
    /**
     * 选择多行列表
     */
    public function getMultiHtml($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "field"=>"id,name,pid",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $result=$checkResult["result"];
                $result=app("ltcmsFormat")->recursionArr($result);//递归组装
                $selectMap=array();
                if(isset($condition["selectId"]) && isset($condition["dataId"])){
                    if($final_arr["error_no"]==0)
                    {
                        $paramsObj=paramsObj();
                        $paramsObj->params=array(
                            'dataType' =>$condition["dataType"],
                            'dataId' => $condition["dataId"],
                            'id' => $condition["selectId"],
                        );
                        $checkResult=app("S_Admin_category")->getParentVal($paramsObj);
                        if($checkResult["error_no"]==0){
                            $selectMap=$checkResult["result"];
                            $selectMap["data"]=array_column($selectMap["data"],"id");
                        }else{
                            $final_arr=logCallErrorMsg($final_arr,$checkResult);
                        }
                    }
                }
                if($final_arr["error_no"]==0)
                {
                    $result=app("ltcmsFormat")->recursionToMultihtml($result,$selectMap);  //转换成html
                    $return=array();
                    $return["result"]=$result;
                    $final_arr["result"]=$return;
                }
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    /**
     * 选择数据html
     */
    public function getHtml($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "field"=>"id,name,pid",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $result=$checkResult["result"];
                $result=app("ltcmsFormat")->recursionArr($result);//递归组装
                if(isset($condition["selectId"])){
                    $result=app("ltcmsFormat")->recursionTohtml($result,$condition["selectId"]);  //转换成html
                }else{
                    $result=app("ltcmsFormat")->recursionTohtml($result);  //转换成html
                }
                $return=array();
                $return["result"]=$result;
                $final_arr["result"]=$return;
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    /**
     * 分类显示
     */
    public function show($paramObj="")
    {
        $dataObj=paramsObj();
        $dataObj->request=paramsObj();
        $dataObj->data=paramsObj();

        $final_arr=logInit();
        if($final_arr["error_no"]==0){
            $mixed=parseToArr($paramObj,"mixed",0);
            $params=parseToArr($paramObj,"params",array());
            $messages=parseToArr($paramObj,"messages",array());
            $rules=array(
                'extraData' => '',
            );
            $dataDefault=array();
            $paramsObj=paramsObj();
            $paramsObj->params=$params;
            $paramsObj->mixed=$mixed;
            $paramsObj->rules=$rules;
            $paramsObj->messages=$messages;
            $paramsObj->dataDefault=$dataDefault;
            $checkResult = app("verifyParam")::validatorRequest($paramsObj);
            if($checkResult["error_no"]==0){
                $dataObj->request=$checkResult["result"];
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        if($final_arr["error_no"]==0)
        {
            $condition=app("P_tag_plugin")->parseCondition($dataObj->request->extraData);
            $paramsObj=paramsObj();
            $paramsObj->params=array(
                "disabled"=>"1",
                "field"=>"id,name,catDir,linkurl,dataType,dataId",
            );
            if($condition && is_array($condition)){
                $paramsObj->params=array_merge($paramsObj->params,$condition);
            }
            if(isset($paramsObj->params["pid"])){
                if(!is_numeric($paramsObj->params["pid"])){
                    $paramsObj->params["pid"]=0;
                }
            }else{
                $paramsObj->params["pid"]=0;
            }
            $checkResult = app("S_Admin_category")->allData($paramsObj);
            if($checkResult["error_no"]==0){
                $return=array();
                $return["result"]=$checkResult["result"];
                $final_arr["result"]=$return;
            }else{
                $final_arr=logCallErrorMsg($final_arr,$checkResult);
            }
        }
        return $final_arr;
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}

?>
